@@ -27,8 +27,6 @@
 #include "tls_test_keys.h"
 
 
-int curl_check_version (const char *req_version, ...);
-
 FILE *
 setup_ca_cert ()
 {
@@ -73,6 +71,7 @@ test_daemon_get (void *cls,
   CURLcode errornum;
   char url[255];
   size_t len;
+  (void)cls;    /* Unused. Silent compiler warning. */
 
   len = strlen (test_data);
   if (NULL == (cbc.buf = malloc (sizeof (char) * len)))
@@ -84,7 +83,9 @@ test_daemon_get (void *cls,
   cbc.pos = 0;
 
   /* construct url - this might use doc_path */
-  gen_test_file_url (url, port);
+  gen_test_file_url (url,
+                     sizeof (url),
+                     port);
 
   c = curl_easy_init ();
 #if DEBUG_HTTPS_TEST
@@ -108,7 +109,7 @@ test_daemon_get (void *cls,
     curl_easy_setopt (c, CURLOPT_CAINFO, ca_cert_file_name);
   curl_easy_setopt (c, CURLOPT_SSL_VERIFYHOST, 0);
   curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
-  
+
   /* NOTE: use of CONNECTTIMEOUT without also
      setting NOSIGNAL results in really weird
      crashes on my system! */
@@ -164,12 +165,14 @@ copyBuffer (void *ptr, size_t size, size_t nmemb, void *ctx)
  */
 int
 http_ahc (void *cls, struct MHD_Connection *connection,
-          const char *url, const char *method, const char *upload_data,
-          const char *version, size_t *upload_data_size, void **ptr)
+          const char *url, const char *method, const char *version,
+          const char *upload_data, size_t *upload_data_size, void **ptr)
 {
   static int aptr;
   struct MHD_Response *response;
   int ret;
+  (void)cls;(void)url;(void)version;            /* Unused. Silent compiler warning. */
+  (void)upload_data;(void)upload_data_size;     /* Unused. Silent compiler warning. */
 
   if (0 != strcmp (method, MHD_HTTP_METHOD_GET))
     return MHD_NO;              /* unexpected method */
@@ -191,11 +194,13 @@ http_ahc (void *cls, struct MHD_Connection *connection,
 /* HTTP access handler call back */
 int
 http_dummy_ahc (void *cls, struct MHD_Connection *connection,
-                const char *url, const char *method, const char *upload_data,
-                const char *version, size_t *upload_data_size,
+                const char *url, const char *method, const char *version,
+                const char *upload_data, size_t *upload_data_size,
                 void **ptr)
 {
-  return 0;
+  (void)cls;(void)connection;(void)url;(void)method;(void)version;      /* Unused. Silent compiler warning. */
+  (void)upload_data;(void)upload_data_size;(void)ptr;                   /* Unused. Silent compiler warning. */
+ return 0;
 }
 
 /**
@@ -258,68 +263,87 @@ send_curl_req (char *url, struct CBC * cbc, const char *cipher_suite,
 /**
  * compile test file url pointing to the current running directory path
  *
- * @param url - char buffer into which the url is compiled
+ * @param[out] url - char buffer into which the url is compiled
+ * @param url_len number of bytes available in url
  * @param port port to use for the test
  * @return -1 on error
  */
 int
-gen_test_file_url (char *url, int port)
+gen_test_file_url (char *url,
+                   size_t url_len,
+                   int port)
 {
   int ret = 0;
   char *doc_path;
   size_t doc_path_len;
   /* setup test file path, url */
+#ifdef PATH_MAX
   doc_path_len = PATH_MAX > 4096 ? 4096 : PATH_MAX;
+#else  /* ! PATH_MAX */
+  doc_path_len = 4096;
+#endif /* ! PATH_MAX */
+#ifdef WINDOWS
+  size_t i;
+#endif /* ! WINDOWS */
   if (NULL == (doc_path = malloc (doc_path_len)))
     {
       fprintf (stderr, MHD_E_MEM);
       return -1;
     }
-  if (getcwd (doc_path, doc_path_len) == NULL)
+  if (NULL == getcwd (doc_path, doc_path_len))
     {
-      fprintf (stderr, "Error: failed to get working directory. %s\n",
+      fprintf (stderr,
+               "Error: failed to get working directory. %s\n",
                strerror (errno));
-      ret = -1;
+      free (doc_path);
+      return -1;
     }
 #ifdef WINDOWS
+  for (i = 0; i < doc_path_len; i++)
   {
-    int i;
-    for (i = 0; i < doc_path_len; i++)
-    {
-      if (doc_path[i] == 0)
-        break;
-      if (doc_path[i] == '\\')
+    if (doc_path[i] == 0)
+      break;
+    if (doc_path[i] == '\\')
       {
         doc_path[i] = '/';
       }
-      if (doc_path[i] != ':')
-        continue;
-      if (i == 0)
-        break;
-      doc_path[i] = doc_path[i - 1];
-      doc_path[i - 1] = '/';
-    }
+    if (doc_path[i] != ':')
+      continue;
+    if (i == 0)
+      break;
+    doc_path[i] = doc_path[i - 1];
+    doc_path[i - 1] = '/';
   }
 #endif
-  /* construct url - this might use doc_path */
-  if (sprintf (url, "%s:%d%s/%s", "https://127.0.0.1", port,
-               doc_path, "urlpath") < 0)
+  /* construct url */
+  if (snprintf (url,
+                url_len,
+                "%s:%d%s/%s",
+                "https://127.0.0.1",
+                port,
+                doc_path,
+                "urlpath") >= (long long)url_len)
     ret = -1;
 
   free (doc_path);
   return ret;
 }
 
+
 /**
  * test HTTPS file transfer
  */
 int
-test_https_transfer (void *cls, const char *cipher_suite, int proto_version)
+test_https_transfer (void *cls,
+                     int port,
+                     const char *cipher_suite,
+                     int proto_version)
 {
   int len;
   int ret = 0;
   struct CBC cbc;
   char url[255];
+  (void)cls;    /* Unused. Silent compiler warning. */
 
   len = strlen (test_data);
   if (NULL == (cbc.buf = malloc (sizeof (char) * len)))
@@ -330,13 +354,16 @@ test_https_transfer (void *cls, const char *cipher_suite, int proto_version)
   cbc.size = len;
   cbc.pos = 0;
 
-  if (gen_test_file_url (url, DEAMON_TEST_PORT))
+  if (gen_test_file_url (url,
+                         sizeof (url),
+                         port))
     {
       ret = -1;
       goto cleanup;
     }
 
-  if (CURLE_OK != send_curl_req (url, &cbc, cipher_suite, proto_version))
+  if (CURLE_OK !=
+      send_curl_req (url, &cbc, cipher_suite, proto_version))
     {
       ret = -1;
       goto cleanup;
@@ -344,8 +371,8 @@ test_https_transfer (void *cls, const char *cipher_suite, int proto_version)
 
   /* compare test file & daemon responce */
   if ( (len != strlen (test_data)) ||
-       (memcmp (cbc.buf, 
-		test_data, 
+       (memcmp (cbc.buf,
+		test_data,
 		len) != 0) )
     {
       fprintf (stderr, "Error: local file & received file differ.\n");
@@ -362,21 +389,33 @@ cleanup:
  * @param d
  * @param daemon_flags
  * @param arg_list
- * @return
+ * @return port number on success or zero on failure
  */
 int
-setup_testcase (struct MHD_Daemon **d, int daemon_flags, va_list arg_list)
+setup_testcase (struct MHD_Daemon **d, int port, int daemon_flags, va_list arg_list)
 {
-  *d = MHD_start_daemon_va (daemon_flags, DEAMON_TEST_PORT,
+  *d = MHD_start_daemon_va (daemon_flags, port,
                             NULL, NULL, &http_ahc, NULL, arg_list);
 
   if (*d == NULL)
     {
       fprintf (stderr, MHD_E_SERVER_INIT);
-      return -1;
+      return 0;
     }
 
-  return 0;
+  if (0 == port)
+    {
+      const union MHD_DaemonInfo *dinfo;
+      dinfo = MHD_get_daemon_info (*d, MHD_DAEMON_INFO_BIND_PORT);
+      if (NULL == dinfo || 0 == dinfo->port)
+        {
+          MHD_stop_daemon (*d);
+          return 0;
+        }
+      port = (int)dinfo->port;
+    }
+
+  return port;
 }
 
 void
@@ -388,7 +427,7 @@ teardown_testcase (struct MHD_Daemon *d)
 int
 setup_session (gnutls_session_t * session,
                gnutls_datum_t * key,
-               gnutls_datum_t * cert, 
+               gnutls_datum_t * cert,
 	       gnutls_certificate_credentials_t * xcred)
 {
   int ret;
@@ -397,7 +436,7 @@ setup_session (gnutls_session_t * session,
   gnutls_certificate_allocate_credentials (xcred);
   key->size = strlen (srv_key_pem) + 1;
   key->data = malloc (key->size);
-  if (NULL == key->data) 
+  if (NULL == key->data)
      {
        gnutls_certificate_free_credentials (*xcred);
 	return -1;
@@ -408,7 +447,7 @@ setup_session (gnutls_session_t * session,
   if (NULL == cert->data)
     {
         gnutls_certificate_free_credentials (*xcred);
-	free (key->data); 
+	free (key->data);
 	return -1;
     }
   memcpy (cert->data, srv_self_signed_cert_pem, cert->size);
@@ -424,8 +463,8 @@ setup_session (gnutls_session_t * session,
        free (key->data);
        return -1;
     }
-  gnutls_credentials_set (*session, 
-			  GNUTLS_CRD_CERTIFICATE, 
+  gnutls_credentials_set (*session,
+			  GNUTLS_CRD_CERTIFICATE,
 			  *xcred);
   return 0;
 }
@@ -450,16 +489,19 @@ teardown_session (gnutls_session_t session,
 /* TODO test_wrap: change sig to (setup_func, test, va_list test_arg) */
 int
 test_wrap (const char *test_name, int
-           (*test_function) (void * cls, const char *cipher_suite,
+           (*test_function) (void * cls, int port, const char *cipher_suite,
                              int proto_version), void * cls,
+           int port,
            int daemon_flags, const char *cipher_suite, int proto_version, ...)
 {
   int ret;
   va_list arg_list;
   struct MHD_Daemon *d;
+  (void)cls;    /* Unused. Silent compiler warning. */
 
   va_start (arg_list, proto_version);
-  if (setup_testcase (&d, daemon_flags, arg_list) != 0)
+  port = setup_testcase (&d, port, daemon_flags, arg_list);
+  if (0 == port)
     {
       va_end (arg_list);
       fprintf (stderr, "Failed to setup testcase %s\n", test_name);
@@ -468,7 +510,7 @@ test_wrap (const char *test_name, int
 #if 0
   fprintf (stdout, "running test: %s ", test_name);
 #endif
-  ret = test_function (NULL, cipher_suite, proto_version);
+  ret = test_function (NULL, port, cipher_suite, proto_version);
 #if 0
   if (ret == 0)
     {
@@ -483,3 +525,22 @@ test_wrap (const char *test_name, int
   va_end (arg_list);
   return ret;
 }
+
+int testsuite_curl_global_init (void)
+{
+  CURLcode res;
+#if LIBCURL_VERSION_NUM >= 0x073800
+  if (CURLSSLSET_OK != curl_global_sslset(CURLSSLBACKEND_GNUTLS, NULL, NULL))
+    {
+      if (CURLSSLSET_TOO_LATE == curl_global_sslset(CURLSSLBACKEND_OPENSSL, NULL, NULL))
+        fprintf (stderr, "WARNING: libcurl was already initialised.\n");
+    }
+#endif /* LIBCURL_VERSION_NUM >= 0x07380 */
+  res = curl_global_init (CURL_GLOBAL_ALL);
+  if (CURLE_OK != res)
+    {
+      fprintf (stderr, "libcurl initialisation error: %s\n", curl_easy_strerror(res));
+      return 0;
+    }
+  return 1;
+}
